--[[
Copyright 2009, 2010, 2011 João Cardoso
Blitz is distributed under the terms of the GNU General Public License (or the Lesser GPL).
This file is part of Blitz.

Blitz is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Blitz is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Blitz. If not, see <http://www.gnu.org/licenses/>.
--]]

local Options = LibStub('Sushi-2.0'):CreateWidget('Container')
local Tutorials = LibStub('CustomTutorials-2.0')
local L = Blitz_Locals


--[[ Options ]]--

function Options:Startup()
	local Author = self:CreateFontString(nil, nil, 'GameFontDisableSmall')
	Author:SetText('Copyright 2009-2011 João Cardoso')
	Author:SetPoint('BOTTOMRIGHT', -4, 4)

	self:SetParent(BlitzOptions)
	self:SetPoint('BOTTOMRIGHT', -4, 5)
	self:SetPoint('TOPLEFT', 4, -11)
	self:SetSize(0, 0)

	self:SetLayout('List')
	self:SetChildren('Initialize')
	self.Startup = nil
end

function Options:Initialize()
	self:CreateHeader('Blitz', 'GameFontNormalLarge')
	self:CreateHeader('Description', 'GameFontHighlightSmall').insets = {bottom = 11}
	
	self:Create('CheckButton', 'Accept')
	self:Create('CheckButton', 'Deliver')
	self:Create('CheckButton', 'SelectReward', nil, 'Deliver')
	self:Create('CheckButton', 'Manual')
	
	local Dropdown = self:Create('Dropdown', Blitz_Manual and 'AutomateKey' or 'ManualKey', 'Key')
	Dropdown:AddLine('Alt', ALT_KEY)
	Dropdown:AddLine('Control', CTRL_KEY)
	Dropdown:AddLine('Shift', SHIFT_KEY)
	Dropdown:AddLine(false, NONE_KEY)
	Dropdown:SetWidth(135)
end

function Options:CreateHeader(text, font)
	local child = self:CreateChild('Header')
	child:SetText(L[text] or text)
	child:SetFont(font)
	return child
end

function Options:Create(class, text, arg, parent)
	local arg = 'Blitz_' .. (arg or text)
	local child = self:CreateChild(class)
	child:SetDisabled(parent and not _G['Blitz_'..parent])
	child:SetDescription(L[text .. 'Desc'])
	child:SetLabel(L[text] or text)
	child:SetValue(_G[arg])
	child:SetSmall(parent)
	
	child.insets = {left = parent and 10 or 0}
	child:RegisterCallback('OnValueChanged', function(v)
		_G[arg] = v
	end)
	return child
end


--[[ Tutorials ]]--

Tutorials.RegisterTutorials('Blitz', {
	savedvariable = 'Blitz_Tutorials',
	title = L.Welcome,
	
	{
		text = L.Tutorial1,
		image = 'Interface\\Addons\\Blitz\\Media\\Tutorial',
		shineTop = 4, shineBottom = -4, shineLeft = -6,
		shineRight = BlitzText:GetWidth() + 10,
		shine = Blitz,
		point = 'TOPRIGHT',
		x = -25, y = -180,
	},
	{
		text = L.Tutorial2,
		shine = MainMenuMicroButton,
		shineTop = -21, shineBottom = 1,
		shineLeft = -2, shineRight = 2,
		point = 'TOPRIGHT',
		x = -25, y = -180,
	},
})

Tutorials.TriggerTutorial('Blitz', 2)
Options:Startup()